Changelog
=========

- new MAJOR version for incompatible API changes,
- new MINOR version for added functionality in a backwards compatible manner
- new PATCH version for backwards compatible bug fixes

v2.0.2
--------
2022-03-29: remedy mypy Untyped decorator makes function "cli_info" untyped

v2.0.1
--------
2022-03-25: fix github actions windows test

v2.0.0
-------
2021-11-23:
    - add "setup.py test" detection

v1.0.2
-------
2021-11-22:
    - remove second github action yml
    - fix "setup.py test"

v1.0.1
------
2021-11-21: implement github actions

v1.0.0
------
2021-11-19: initial release
